@@ -139,7 +139,6 @@ class GalleryBlock(blocks.StructBlock):
 
 
 class GallerySliderBlock(GalleryBlock):
-
     class Meta:
         template = '%s/common/gallery_slider.html' % constants.BLOCK_TEMPLATES_PATH
         label = "Gallery Slider"
@@ -153,6 +152,31 @@ class PersonBlock(blocks.StructBlock):
         label = "Person"
 
 
+class ClassicNumbersItem(blocks.StructBlock):
+    number = blocks.IntegerBlock(required=True)
+    unit = blocks.CharBlock(required=False, help_text='unité de mesure')
+    content = TextBlock(label="Content")
+
+
+class NumbersBlock(blocks.StreamBlock):
+    classic = ClassicNumbersItem()
+
+    class Meta:
+        template = '%s/entries/numbers_block.html' % constants.BLOCK_TEMPLATES_PATH
+
+
+class ClassicAccordionItem(blocks.StructBlock):
+    head = TextBlock(label="Head")
+    content = TextBlock(label="Head")
+
+
+class AccordionBlock(blocks.StreamBlock):
+    classic = ClassicAccordionItem()
+
+    class Meta:
+        template = '%s/entries/accordion_block.html' % constants.BLOCK_TEMPLATES_PATH
+
+
 class EntryBlock(Mocker, blocks.StructBlock):
     bg_desktop = blocks.StreamBlock(
         [
