@@ -140,4 +140,4 @@ class CardsEntry(EntryBlock):
     class Meta:
         template = '%s/entries/cards.html' % constants.BLOCK_TEMPLATES_PATH
         label = "Cards"
-        #  icon = 'image'
+        icon = 'grip'
