@@ -9,15 +9,15 @@ class SvgEntry(EntryBlock):
 
     def mock(self, force_file=None, size='m', *args, **kwargs):
         if 'theme' in kwargs:
-            file = self.mocker.SVG_CONTENT_WIDTH_LIGHT \
-                if kwargs['theme'] == constants.THEME_LIGHT else self.mocker.SVG_CONTENT_WIDTH_SPACE
+            file = self.SVG_CONTENT_WIDTH_LIGHT \
+                if kwargs['theme'] == constants.THEME_LIGHT else self.SVG_CONTENT_WIDTH_SPACE
         else:
-            file = self.mocker.SVG_CONTENT_WIDTH_LIGHT
+            file = self.SVG_CONTENT_WIDTH_LIGHT
         self.mock_data.update({
             'type': 'svg',
             'value': {
                 'svg': {
-                    'file': self.mocker.file(file if not force_file else force_file).id,
+                    'file': self.file(file if not force_file else force_file).id,
                     'size': size
                 }
             }
