@@ -43,8 +43,8 @@ PortfoliosEntry = get_class('cms.blocks.entries', 'PortfoliosEntry')
 GalleryEntry = get_class('cms.blocks.entries', 'GalleryEntry')
 StreamContentEntry = get_class('cms.blocks.entries', 'StreamContentEntry')
 GallerySliderEntry = get_class('cms.blocks.entries', 'GallerySliderEntry')
-
-
+PricingEntry = get_class('cms.blocks.entries', 'PricingEntry')
+ReviewEntry = get_class('cms.blocks.entries', 'ReviewEntry')
 
 SocialShare = get_class('cms.blocks.static', 'SocialShare')
 SocialLinks = get_class('cms.blocks.static', 'SocialLinks')
@@ -147,8 +147,12 @@ class AGenericPage(Page):
         ('gallery', GalleryEntry()),
         ('gallery_slider', GallerySliderEntry()),
         ('stream_content', StreamContentEntry()),
+        ('pricing', PricingEntry()),
+        ('review', ReviewEntry()),
     ], blank=True)
 
+    page_script = models.TextField(default='', blank=True)
+
     content_panels = [
         StreamFieldPanel('body'),
     ]
@@ -167,6 +171,7 @@ class AGenericPage(Page):
     settings_panels = [
         FieldPanel('title'),
         FieldPanel('slug'),
+        FieldPanel('page_script'),
         FieldPanel('theme'),
         FieldPanel('amp_active'),
         SnippetChooserPanel('navigation'),
