@@ -6,6 +6,7 @@ from django import template
 from django.conf import settings
 from wagtail.embeds.embeds import get_embed
 from wagtail.embeds.exceptions import EmbedException
+from wagtail.core.models import Site
 
 from webspace.cms import constants
 from webspace.cms.amp.utils import amp_mode_active
@@ -100,7 +101,8 @@ class AMPStyles(template.Node):
             href = tree.get('href')
             request = context['request']
             http = 'https://' if not settings.DEBUG else 'http://'
-            host = request.site.hostname
+            site = Site.find_for_request(request)
+            host = site.hostname
             if host == 'localhost':
                 host += ':8080'
             url = http + host + href
